@@ -10,9 +10,10 @@ import ipo2_sup as supermod
 
 etree_ = None
 Verbose_import_ = False
-(   XMLParser_import_none, XMLParser_import_lxml,
+(
+    XMLParser_import_none, XMLParser_import_lxml,
     XMLParser_import_elementtree
-    ) = range(3)
+) = range(3)
 XMLParser_import_library = None
 try:
     # lxml
@@ -52,9 +53,10 @@ except ImportError:
                     raise ImportError(
                         "Failed to import ElementTree from any known place")
 
+
 def parsexml_(*args, **kwargs):
     if (XMLParser_import_library == XMLParser_import_lxml and
-        'parser' not in kwargs):
+            'parser' not in kwargs):
         # Use the lxml ElementTree compatible parser so that, e.g.,
         #   we ignore comments.
         kwargs['parser'] = etree_.ETCompatXMLParser()
@@ -71,6 +73,7 @@ ExternalEncoding = 'ascii'
 # Data representation classes
 #
 
+
 class PurchaseOrderTypeSub(supermod.PurchaseOrderType):
     def __init__(self, orderDate=None, shipTo=None, billTo=None, comment=None, items=None):
         super(PurchaseOrderTypeSub, self).__init__(orderDate, shipTo, billTo, comment, items, )
@@ -113,7 +116,6 @@ supermod.itemType.subclass = itemTypeSub
 # end class itemTypeSub
 
 
-
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
@@ -135,7 +137,8 @@ def parse(inFilename):
     # Enable Python to collect the space used by the DOM.
     doc = None
     sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(sys.stdout, 0, name_=rootTag,
+    rootObj.export(
+        sys.stdout, 0, name_=rootTag,
         namespacedef_='',
         pretty_print=True)
     return rootObj
@@ -153,7 +156,8 @@ def parseEtree(inFilename):
     # Enable Python to collect the space used by the DOM.
     doc = None
     rootElement = rootObj.to_etree(None, name_=rootTag)
-    content = etree_.tostring(rootElement, pretty_print=True,
+    content = etree_.tostring(
+        rootElement, pretty_print=True,
         xml_declaration=True, encoding="utf-8")
     sys.stdout.write(content)
     sys.stdout.write('\n')
@@ -173,7 +177,8 @@ def parseString(inString):
     # Enable Python to collect the space used by the DOM.
     doc = None
     sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(sys.stdout, 0, name_=rootTag,
+    rootObj.export(
+        sys.stdout, 0, name_=rootTag,
         namespacedef_='')
     return rootObj
 
@@ -181,9 +186,9 @@ def parseString(inString):
 def parseLiteral(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
-    rootTag, rootClass = get_root_tag(rootNode)
+    roots = get_root_tag(rootNode)
+    rootClass = roots[1]
     if rootClass is None:
-        rootTag = 'purchaseOrder'
         rootClass = supermod.PurchaseOrderType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -201,6 +206,7 @@ USAGE_TEXT = """
 Usage: python ???.py <infilename>
 """
 
+
 def usage():
     print USAGE_TEXT
     sys.exit(1)
@@ -211,11 +217,9 @@ def main():
     if len(args) != 1:
         usage()
     infilename = args[0]
-    root = parse(infilename)
+    parse(infilename)
 
 
 if __name__ == '__main__':
     #import pdb; pdb.set_trace()
     main()
-
-
