@@ -10,9 +10,10 @@ import out2_sup as supermod
 
 etree_ = None
 Verbose_import_ = False
-(   XMLParser_import_none, XMLParser_import_lxml,
+(
+    XMLParser_import_none, XMLParser_import_lxml,
     XMLParser_import_elementtree
-    ) = range(3)
+) = range(3)
 XMLParser_import_library = None
 try:
     # lxml
@@ -52,9 +53,10 @@ except ImportError:
                     raise ImportError(
                         "Failed to import ElementTree from any known place")
 
+
 def parsexml_(*args, **kwargs):
     if (XMLParser_import_library == XMLParser_import_lxml and
-        'parser' not in kwargs):
+            'parser' not in kwargs):
         # Use the lxml ElementTree compatible parser so that, e.g.,
         #   we ignore comments.
         kwargs['parser'] = etree_.ETCompatXMLParser()
@@ -71,6 +73,7 @@ ExternalEncoding = 'ascii'
 # Data representation classes
 #
 
+
 class peopleSub(supermod.people):
     def __init__(self, comments=None, person=None, programmer=None, python_programmer=None, java_programmer=None):
         super(peopleSub, self).__init__(comments, person, programmer, python_programmer, java_programmer, )
@@ -135,8 +138,8 @@ supermod.special_agent.subclass = special_agentSub
 
 
 class boosterSub(supermod.booster):
-    def __init__(self, firstname=None, lastname=None, other_name=None, classxx=None, other_value=None, type_=None, client_handler=None):
-        super(boosterSub, self).__init__(firstname, lastname, other_name, classxx, other_value, type_, client_handler, )
+    def __init__(self, firstname=None, lastname=None, other_name=None, class_=None, other_value=None, type_=None, client_handler=None):
+        super(boosterSub, self).__init__(firstname, lastname, other_name, class_, other_value, type_, client_handler, )
 supermod.booster.subclass = boosterSub
 # end class boosterSub
 
@@ -155,7 +158,6 @@ supermod.client_handlerType.subclass = client_handlerTypeSub
 # end class client_handlerTypeSub
 
 
-
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
@@ -177,7 +179,8 @@ def parse(inFilename):
     # Enable Python to collect the space used by the DOM.
     doc = None
     sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(sys.stdout, 0, name_=rootTag,
+    rootObj.export(
+        sys.stdout, 0, name_=rootTag,
         namespacedef_='',
         pretty_print=True)
     return rootObj
@@ -194,12 +197,15 @@ def parseEtree(inFilename):
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
     doc = None
-    rootElement = rootObj.to_etree(None, name_=rootTag)
-    content = etree_.tostring(rootElement, pretty_print=True,
+    mapping = {}
+    rootElement = rootObj.to_etree(None, name_=rootTag, mapping_=mapping)
+    reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
+    content = etree_.tostring(
+        rootElement, pretty_print=True,
         xml_declaration=True, encoding="utf-8")
     sys.stdout.write(content)
     sys.stdout.write('\n')
-    return rootObj, rootElement
+    return rootObj, rootElement, mapping, reverse_mapping
 
 
 def parseString(inString):
@@ -215,7 +221,8 @@ def parseString(inString):
     # Enable Python to collect the space used by the DOM.
     doc = None
     sys.stdout.write('<?xml version="1.0" ?>\n')
-    rootObj.export(sys.stdout, 0, name_=rootTag,
+    rootObj.export(
+        sys.stdout, 0, name_=rootTag,
         namespacedef_='')
     return rootObj
 
@@ -223,9 +230,9 @@ def parseString(inString):
 def parseLiteral(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
-    rootTag, rootClass = get_root_tag(rootNode)
+    roots = get_root_tag(rootNode)
+    rootClass = roots[1]
     if rootClass is None:
-        rootTag = 'people'
         rootClass = supermod.people
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -243,6 +250,7 @@ USAGE_TEXT = """
 Usage: python ???.py <infilename>
 """
 
+
 def usage():
     print USAGE_TEXT
     sys.exit(1)
@@ -253,11 +261,9 @@ def main():
     if len(args) != 1:
         usage()
     infilename = args[0]
-    root = parse(infilename)
+    parse(infilename)
 
 
 if __name__ == '__main__':
     #import pdb; pdb.set_trace()
     main()
-
-
